@@ -118,8 +118,8 @@ class MosmixS:
     def content_age_sec(self) -> int:
         return int((datetime.now() - self.issue_time()).total_seconds())
 
-    def is_expired(self):
-        return self.content_age_sec() > 60 and (datetime.now() - self.__fetch_datetime).total_seconds() > (7 * 60)
+    def elapsed_sec_fetched(self):
+        return int((datetime.now() - self.__fetch_datetime).total_seconds())
 
     def rad1h(self, dt: datetime) -> float:
         if self.__rad1h_series is None:
